@@ -1,5 +1,5 @@
+#include <mcrypt.h>
 #include <stdio.h>
-#include <lcrypt.h>
 #include <strings.h>
 
 /* Prints plaintext and ciphertext in hex for all the algorithms */
